import { LitElement } from 'lit';
declare const UUISliderElement_base: (new (...args: any[]) => import("@umbraco-ui/uui-base/lib/mixins").UUIFormControlMixinElement<FormDataEntryValue | FormData>) & typeof LitElement;
/**
 * @element uui-slider
 * @description - Native `<input type="range">` wrapper.
 * @fires UUISliderEvent#input on input
 * @extends UUIFormControlMixin
 */
export declare class UUISliderElement extends UUISliderElement_base {
    #private;
    /**
     * This is a static class field indicating that the element is can be used inside a native form and participate in its events. It may require a polyfill, check support here https://developer.mozilla.org/en-US/docs/Web/API/HTMLElement/attachInternals.  Read more about form controls here https://web.dev/more-capable-form-controls/
     * @type {boolean}
     */
    static readonly formAssociated = true;
    /**
     * Hides the numbers representing the value of each steps. Dots will still be visible
     * @type {boolean}
     * @attr 'hide-step-values'
     * @default false
     */
    hideStepValues: boolean;
    /**
     * Hides the value label on the thumb.
     * @type {boolean}
     * @attr 'hide-value-label'
     * @default false
     */
    hideValueLabel: boolean;
    /**
     * This is a minimum value of the input.
     * @type {number}
     * @attr
     * @default 0
     */
    min: number;
    /**
     * This is a maximum value of the input.
     * @type {number}
     * @attr
     * @default 100
     */
    max: number;
    /**
     * This reflects the behavior of a native input step attribute.
     * @type {number}
     * @attr
     * @default 1
     */
    get step(): number;
    set step(value: number);
    /**
     * This is a value property of the uui-slider.
     * @type {string}
     * @attr
     * @default ''
     */
    get value(): FormDataEntryValue | FormData;
    set value(newVal: FormDataEntryValue | FormData);
    /**
     * Disables the input.
     * @type {boolean}
     * @attr
     * @default false
     */
    disabled: boolean;
    /**
     * Label to be used for aria-label and eventually as visual label
     * @type {string}
     * @attr
     */
    label: string;
    private _input;
    private _track;
    constructor();
    /**
     * This method enables <label for="..."> to focus the select
     */
    focus(): Promise<void>;
    blur(): Promise<void>;
    /**
     * This method enables <label for="..."> to open the select
     */
    click(): Promise<void>;
    protected getFormElement(): HTMLElement;
    connectedCallback(): void;
    disconnectedCallback(): void;
    firstUpdated(): void;
    updated(changedProperties: Map<string | number | symbol, unknown>): void;
    private _updateSteps;
    private _stepWidth;
    private _calculateStepWidth;
    private onWindowResize;
    private _onKeypress;
    protected _steps: number[];
    protected _sliderPosition: string;
    private _calculateSliderPosition;
    private _onInput;
    private _onChange;
    render(): import("lit-html").TemplateResult<1>;
    static styles: import("lit").CSSResult[];
}
declare global {
    interface HTMLElementTagNameMap {
        'uui-slider': UUISliderElement;
    }
}
export {};
